@@ -1,6 +1,7 @@
 /*
   GNOME Commander - A GNOME based file manager
   Copyright (C) 2001-2006 Marcus Bjurman
+  Copyright (C) 2007-2009 Piotr Eljasiak
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,14 +21,11 @@
 #ifndef __GNOME_CMD_ADVRENAME_LEXER_H__
 #define __GNOME_CMD_ADVRENAME_LEXER_H__
 
-
 #include "gnome-cmd-file.h"
 
-void gnome_cmd_advrename_reset_counter(unsigned start, unsigned precision, unsigned step);
-void gnome_cmd_advrename_parse_fname(const char *fname);
-char *gnome_cmd_advrename_gen_fname(char *new_fname, size_t new_fname_size, GnomeCmdFile *finfo);
+void gnome_cmd_advrename_reset_counter(long start=1, int precision=-1, int step=1);
+void gnome_cmd_advrename_parse_template(const char *template_string, gboolean &has_counters);
+char *gnome_cmd_advrename_gen_fname(char *new_fname, size_t new_fname_size, GnomeCmdFile *f);
 
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_ADVRENAME_LEXER_H__
