@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -126,6 +127,15 @@ inline _GnomeCmdConnectDialogPrivate::_GnomeCmdConnectDialogPrivate()
     user_entry = gtk_entry_new ();
     password_entry = gtk_entry_new ();
 
+    gtk_entry_set_activates_default (GTK_ENTRY (alias_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (uri_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (server_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (share_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (port_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (folder_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (user_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (password_entry), TRUE);
+
     gtk_entry_set_visibility (GTK_ENTRY (password_entry), FALSE);
 
     // We need an extra ref so we can remove them from the table
@@ -435,7 +445,7 @@ static void port_insert_text (GtkEditable *editable, const gchar *new_text, gint
     if (new_text_length != 1 || !g_ascii_isdigit (new_text[0]))
     {
         gdk_display_beep (gtk_widget_get_display (GTK_WIDGET (editable)));
-        g_signal_stop_emission_by_name (editable, "insert_text");
+        g_signal_stop_emission_by_name (editable, "insert-text");
     }
 }
 
@@ -481,14 +491,13 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     dialog->priv->type_combo = combo = gtk_combo_box_new_text ();
 
     // Keep this in sync with enum ConnectionMethodID in gnome-cmd-con.h
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("SSH"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("FTP (with login)"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Public FTP"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("SSH"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Windows share"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("WebDAV (HTTP)"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Secure WebDAV (HTTPS)"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Custom location"));
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), CON_FTP);     // CON_FTP --> CON_SSH
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Windows share"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("WebDAV (HTTP)"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Secure WebDAV (HTTPS)"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Custom location"));
     gtk_widget_show (combo);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
     gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
@@ -520,7 +529,7 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     gtk_widget_show (table);
     gtk_container_add (GTK_CONTAINER (align), table);
 
-    g_signal_connect (dialog->priv->port_entry, "insert_text", G_CALLBACK (port_insert_text), NULL);
+    g_signal_connect (dialog->priv->port_entry, "insert-text", G_CALLBACK (port_insert_text), NULL);
 
     setup_for_type (dialog);
 
@@ -549,10 +558,9 @@ GnomeCmdConFtp *gnome_cmd_connect_dialog_new (gboolean has_alias)
     else
         gtk_widget_set_sensitive (conndlg->priv->alias_entry, FALSE);
 
-    ConnectionMethodID method = CON_FTP;        // later: CON_SSH
-    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), method);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), CON_SSH);
 
-    conndlg->priv->use_auth = gnome_cmd_data_get_use_gnome_auth_manager ();
+    conndlg->priv->use_auth = gnome_cmd_data.use_gnome_auth_manager;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (conndlg->priv->auth_check), conndlg->priv->use_auth);
 
     gint response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -581,7 +589,7 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
 {
     g_return_val_if_fail (server != NULL, FALSE);
 
-    GtkWidget *dialog = (GtkWidget *) gtk_type_new (gnome_cmd_connect_dialog_get_type ());
+    GtkWidget *dialog = gtk_widget_new (GNOME_CMD_TYPE_CONNECT_DIALOG, NULL);
 
     g_return_val_if_fail (dialog != NULL, FALSE);
 
@@ -639,23 +647,15 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
 
         const gchar *alias = conndlg->priv->alias ? conndlg->priv->alias->c_str() : NULL;
         const gchar *host = gnome_vfs_uri_get_host_name (uri);      // do not g_free !!
-        const guint  port = gnome_vfs_uri_get_host_port (uri);
-        const gchar *remote_dir = gnome_vfs_uri_get_path (uri);     // do not g_free !!
-        const gchar *user = gnome_vfs_uri_get_user_name (uri);      // do not g_free !!
-        const gchar *password = gnome_vfs_uri_get_password (uri);   // do not g_free !!
 
-        gnome_cmd_con_ftp_set_alias (server, alias);
-        gnome_cmd_con_ftp_set_host_name (server, host);
-        gnome_cmd_con_ftp_set_host_port (server, port);
-        gnome_cmd_con_ftp_set_remote_dir (server, remote_dir);
-        gnome_cmd_con_ftp_set_user_name (server, user);
-        gnome_cmd_con_ftp_set_pw (server, password);
-
-        // do not set con->alias as it is already done in gnome_cmd_con_ftp_set_alias (alias, ...)
+        gnome_cmd_con_set_alias (con, alias);
         gnome_cmd_con_set_uri (con, conndlg->priv->uri_str);
+        gnome_cmd_con_set_host_name (con, host);
         con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (conndlg->priv->type_combo));
         con->gnome_auth = conndlg->priv->use_auth;
 
+        gnome_cmd_con_ftp_set_host_name (server, host);
+
         gnome_vfs_uri_unref (uri);
     }
 
