@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-main-menu.h"
 #include "gnome-cmd-types.h"
@@ -25,6 +27,7 @@
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-con.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-data.h"
 #include "utils.h"
 #include "imageloader.h"
@@ -55,9 +58,9 @@ typedef enum
 typedef struct
 {
     MenuType type;          // Type of item
-    gchar *label;           // The text to use for this menu-item
-    gchar *shortcut;        // The shortcut for this menu-item
-    gchar *tooltip;         // The tooltip of this menu-item
+    const gchar *label;     // The text to use for this menu-item
+    const gchar *shortcut;  // The shortcut for this menu-item
+    const gchar *tooltip;   // The tooltip of this menu-item
     gpointer moreinfo;      // For an item, toggleitem, this is a pointer to the function to call when the item is activated.
     gpointer user_data;     // Data pointer to pass to callbacks
     GnomeUIPixmapType pixmap_type;    // Type of pixmap for the item
@@ -73,8 +76,7 @@ typedef struct
                                      * pointer to the filename string.
                                      */
 
-    GtkWidget *widget;        /* Filled in by gnome_app_create*, you can use this
-                               to tweak the widgets once they have been created */
+    GtkWidget *widget;      // Filled in by gnome_app_create*, you can use this to tweak the widgets once they have been created
 } MenuData;
 
 #define MENUTYPE_END { \
@@ -92,7 +94,7 @@ typedef struct
     NULL }
 
 
-struct _GnomeCmdMainMenuPrivate
+struct GnomeCmdMainMenuPrivate
 {
     GtkWidget *file_menu;
     GtkWidget *edit_menu;
@@ -105,8 +107,9 @@ struct _GnomeCmdMainMenuPrivate
     GtkWidget *help_menu;
 
     GtkWidget *menu_edit_paste;
-    GtkWidget *menu_view_conbuttons;
     GtkWidget *menu_view_toolbar;
+    GtkWidget *menu_view_conbuttons;
+    GtkWidget *menu_view_concombo;
     GtkWidget *menu_view_buttonbar;
     GtkWidget *menu_view_cmdline;
     GtkWidget *menu_view_hidden_files;
@@ -132,8 +135,7 @@ static GtkMenuBarClass *parent_class = NULL;
  * Private functions
  *******************************/
 
-static void
-on_bookmark_selected (GtkMenuItem *menuitem, GnomeCmdBookmark *bookmark)
+static void on_bookmark_selected (GtkMenuItem *menuitem, GnomeCmdBookmark *bookmark)
 {
     g_return_if_fail (bookmark != NULL);
 
@@ -141,15 +143,13 @@ on_bookmark_selected (GtkMenuItem *menuitem, GnomeCmdBookmark *bookmark)
 }
 
 
-static void
-on_con_list_list_changed (GnomeCmdConList *con_list, GnomeCmdMainMenu *main_menu)
+static void on_con_list_list_changed (GnomeCmdConList *con_list, GnomeCmdMainMenu *main_menu)
 {
     gnome_cmd_main_menu_update_connections (main_menu);
 }
 
 
-static GtkWidget*
-create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent, MenuData *spec)
+static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent, MenuData *spec)
 {
     GtkWidget *item=NULL;
     GtkWidget *desc, *shortcut;
@@ -212,7 +212,6 @@ create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent, MenuData *spec)
             return NULL;
     }
 
-
     gtk_widget_show (item);
 
     if (spec->type == MENU_TYPE_ITEM)
@@ -229,23 +228,20 @@ create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent, MenuData *spec)
 }
 
 
-static GtkWidget*
-create_menu (GnomeCmdMainMenu *main_menu, MenuData *spec, MenuData *childs)
+static GtkWidget *create_menu (GnomeCmdMainMenu *main_menu, MenuData *spec, MenuData *childs)
 {
-    gint i=0;
-    GtkWidget *submenu, *menu_item;
+    GtkWidget *submenu = gtk_menu_new ();
+    GtkWidget *menu_item = create_menu_item (main_menu, NULL, spec);
 
-    submenu = gtk_menu_new ();
-    menu_item = create_menu_item (main_menu, NULL, spec);
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), submenu);
 
     gtk_widget_ref (menu_item);
     gtk_widget_show (menu_item);
 
-    while (childs[i].type != MENU_TYPE_END) {
+    for (gint i=0; childs[i].type != MENU_TYPE_END; ++i)
+    {
         GtkWidget *child = create_menu_item (main_menu, GTK_MENU (submenu), &childs[i]);
         gtk_menu_shell_append (GTK_MENU_SHELL (submenu), child);
-        i++;
     }
 
     return menu_item;
@@ -262,11 +258,11 @@ add_menu_item (GnomeCmdMainMenu *main_menu,
                GtkSignalFunc callback,
                gpointer user_data)
 {
+    g_return_val_if_fail (GTK_IS_MENU_SHELL (menu), NULL);
+
     GtkWidget *item, *label;
     GtkWidget *pixmap_widget = NULL;
 
-    g_return_val_if_fail (GTK_IS_MENU_SHELL (menu), NULL);
-
     item = gtk_image_menu_item_new ();
 
     if (tooltip)
@@ -303,8 +299,7 @@ add_menu_item (GnomeCmdMainMenu *main_menu,
 }
 
 
-static GtkWidget *
-add_separator (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu)
+static GtkWidget *add_separator (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu)
 {
     MenuData t = MENUTYPE_SEPARATOR;
 
@@ -315,8 +310,7 @@ add_separator (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu)
 }
 
 
-static void
-add_bookmark_menu_item (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCmdBookmark *bookmark)
+static void add_bookmark_menu_item (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCmdBookmark *bookmark)
 {
     GtkWidget *item;
 
@@ -329,8 +323,7 @@ add_bookmark_menu_item (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCm
 }
 
 
-static void
-add_bookmark_group (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCmdBookmarkGroup *group)
+static void add_bookmark_group (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCmdBookmarkGroup *group)
 {
     g_return_if_fail (GTK_IS_MENU_SHELL (menu));
     g_return_if_fail (group != NULL);
@@ -356,14 +349,12 @@ add_bookmark_group (GnomeCmdMainMenu *main_menu, GtkMenuShell *menu, GnomeCmdBoo
 }
 
 
-static void
-update_view_menu (GnomeCmdMainMenu *main_menu);
+static void update_view_menu (GnomeCmdMainMenu *main_menu);
 
 
-static void
-on_switch_orientation (GtkMenuItem *menu_item, GnomeCmdMainMenu *main_menu)
+static void on_switch_orientation (GtkMenuItem *menu_item, GnomeCmdMainMenu *main_menu)
 {
-    gnome_cmd_data_set_list_orientation (!gnome_cmd_data_get_list_orientation ());
+    gnome_cmd_data.list_orientation = !gnome_cmd_data.list_orientation;
 
     gnome_cmd_main_win_update_list_orientation (main_win);
 
@@ -371,15 +362,14 @@ on_switch_orientation (GtkMenuItem *menu_item, GnomeCmdMainMenu *main_menu)
 }
 
 
-static void
-update_view_menu (GnomeCmdMainMenu *main_menu)
+static void update_view_menu (GnomeCmdMainMenu *main_menu)
 {
     gchar *label;
     GtkWidget *item;
     GdkPixmap *pm;
     GdkBitmap *bm;
 
-    if (gnome_cmd_data_get_list_orientation ())
+    if (gnome_cmd_data.list_orientation)
     {
         label = g_strdup (_("Switch to Vertical Layout"));
         pm = IMAGE_get_pixmap (PIXMAP_SWITCH_V);
@@ -392,16 +382,15 @@ update_view_menu (GnomeCmdMainMenu *main_menu)
         bm = IMAGE_get_mask (PIXMAP_SWITCH_H);
     }
 
-    g_list_foreach (main_menu->priv->view_menuitems, (GFunc)gtk_object_destroy, NULL);
+    g_list_foreach (main_menu->priv->view_menuitems, (GFunc) gtk_object_destroy, NULL);
     g_list_free (main_menu->priv->view_menuitems);
     main_menu->priv->view_menuitems = NULL;
 
-    item = add_menu_item (
-        main_menu,
-        GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->view_menu)->submenu),
-        label, NULL,
-        pm, bm,
-        GTK_SIGNAL_FUNC (on_switch_orientation), main_menu);
+    item = add_menu_item (main_menu,
+                          GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->view_menu)->submenu),
+                          label, NULL,
+                          pm, bm,
+                          GTK_SIGNAL_FUNC (on_switch_orientation), main_menu);
 
     g_free (label);
 
@@ -413,8 +402,7 @@ update_view_menu (GnomeCmdMainMenu *main_menu)
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdMainMenu *menu = GNOME_CMD_MAIN_MENU (object);
 
@@ -425,16 +413,14 @@ destroy (GtkObject *object)
 }
 
 
-static void
-map (GtkWidget *widget)
+static void map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
         GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
 
-static void
-class_init (GnomeCmdMainMenuClass *klass)
+static void class_init (GnomeCmdMainMenuClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -445,8 +431,7 @@ class_init (GnomeCmdMainMenuClass *klass)
 }
 
 
-static void
-init (GnomeCmdMainMenu *main_menu)
+static void init (GnomeCmdMainMenu *main_menu)
 {
     MenuData files_menu_uiinfo[] =
     {
@@ -488,16 +473,23 @@ init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("S_ynchonize Directories"), "", NULL,
+            MENU_TYPE_ITEM, _("S_ynchronize Directories"), "", NULL,
             (gpointer) file_sync_dirs, NULL,
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
         },
         MENUTYPE_SEPARATOR,
+        {
+            MENU_TYPE_ITEM, _("Start _GNOME Commander as Root"), "", NULL,
+            (gpointer) command_root_mode, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_DIALOG_AUTHENTICATION,
+            NULL
+        },
+        MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_ITEM, _("_Quit"), "Ctrl+Q", NULL,
             (gpointer) file_exit, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_QUIT,
             NULL
         },
         MENUTYPE_END
@@ -556,25 +548,25 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("Cu_t"), "Ctrl+X", NULL,
             (gpointer) edit_cap_cut, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CUT,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Copy"), "Ctrl+C", NULL,
             (gpointer) edit_cap_copy, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_COPY,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Paste"), "Ctrl+V", NULL,
             (gpointer) edit_cap_paste, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PASTE,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PASTE,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Delete"), "Delete", NULL,
             (gpointer) file_delete, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH,
+            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_TRASH,
             NULL
         },
         MENUTYPE_SEPARATOR,
@@ -588,7 +580,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Search..."), "Alt+F7", NULL,
             (gpointer) edit_search, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
             NULL
         },
         {
@@ -611,28 +603,35 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Back"), "Alt+Left", NULL,
             (gpointer) view_back, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_BACK,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Forward"), "Alt+Right", NULL,
             (gpointer) view_forward, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_FORWARD,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Refresh"), "Ctrl+R", NULL,
             (gpointer) view_refresh, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REFRESH,
             NULL
         },
         MENUTYPE_SEPARATOR,
         {
-            MENU_TYPE_TOGGLEITEM, _("Show Device Buttons"), "", NULL,
-            (gpointer) view_conbuttons, NULL,
-            GNOME_APP_PIXMAP_NONE, NULL,
+            MENU_TYPE_ITEM, _("Open in New _Tab"), "Ctrl+T", NULL,
+            (gpointer) view_new_tab, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
             NULL
         },
+        {
+            MENU_TYPE_ITEM, _("_Close Tab"), "Ctrl+W", NULL,
+            (gpointer) view_close_tab, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLOSE,
+            NULL
+        },
+        MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_TOGGLEITEM, _("Show Toolbar"), "", NULL,
             (gpointer) view_toolbar, NULL,
@@ -640,7 +639,19 @@ init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         {
-            MENU_TYPE_TOGGLEITEM, _("Show Commandline"), "", NULL,
+            MENU_TYPE_TOGGLEITEM, _("Show Device Buttons"), "", NULL,
+            (gpointer) view_conbuttons, NULL,
+            GNOME_APP_PIXMAP_NONE, NULL,
+            NULL
+        },
+        {
+            MENU_TYPE_TOGGLEITEM, _("Show Device List"), "", NULL,
+            (gpointer) view_concombo, NULL,
+            GNOME_APP_PIXMAP_NONE, NULL,
+            NULL
+        },
+        {
+            MENU_TYPE_TOGGLEITEM, _("Show Command Line"), "", NULL,
             (gpointer) view_cmdline, NULL,
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
@@ -713,7 +724,13 @@ init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("Edit _Mime Types..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Keyboard Shortcuts..."), "", NULL,
+            (gpointer) options_edit_shortcuts, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("_MIME Types..."), "", NULL,
             (gpointer) options_edit_mime_types, NULL,
             GNOME_APP_PIXMAP_NONE, 0,
             NULL
@@ -724,14 +741,14 @@ init (GnomeCmdMainMenu *main_menu)
     MenuData connections_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("FTP _Connect..."), "Ctrl+F", NULL,
-            (gpointer) connections_ftp_connect, NULL,
+            MENU_TYPE_ITEM, _("_Remote Server..."), "Ctrl+F", NULL,
+            (gpointer) connections_open, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("FTP _Quick Connect..."), "Ctrl+G", NULL,
-            (gpointer) connections_ftp_quick_connect, NULL,
+            MENU_TYPE_ITEM, _("New Connection..."), "Ctrl+N", NULL,
+            (gpointer) connections_new, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
         },
@@ -749,7 +766,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Keyboard Shortcuts"), "", NULL,
             (gpointer) help_keyboard, NULL,
-            GNOME_APP_PIXMAP_NONE, 0,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
             NULL
         },
         {
@@ -768,7 +785,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_About"), "", NULL,
             (gpointer) help_about, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
+            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_ABOUT,
             NULL
         },
         MENUTYPE_END
@@ -826,35 +843,39 @@ init (GnomeCmdMainMenu *main_menu)
     gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), main_menu->priv->help_menu);
 
     main_menu->priv->menu_edit_paste = edit_menu_uiinfo[2].widget;
-    main_menu->priv->menu_view_conbuttons = view_menu_uiinfo[4].widget;
-    main_menu->priv->menu_view_toolbar = view_menu_uiinfo[5].widget;
-    main_menu->priv->menu_view_cmdline = view_menu_uiinfo[6].widget;
-    main_menu->priv->menu_view_buttonbar = view_menu_uiinfo[7].widget;
-    main_menu->priv->menu_view_hidden_files = view_menu_uiinfo[9].widget;
-    main_menu->priv->menu_view_backup_files = view_menu_uiinfo[10].widget;
+    main_menu->priv->menu_view_toolbar = view_menu_uiinfo[7].widget;
+    main_menu->priv->menu_view_conbuttons = view_menu_uiinfo[8].widget;
+    main_menu->priv->menu_view_concombo = view_menu_uiinfo[9].widget;
+    main_menu->priv->menu_view_cmdline = view_menu_uiinfo[10].widget;
+    main_menu->priv->menu_view_buttonbar = view_menu_uiinfo[11].widget;
+    main_menu->priv->menu_view_hidden_files = view_menu_uiinfo[13].widget;
+    main_menu->priv->menu_view_backup_files = view_menu_uiinfo[14].widget;
     main_menu->priv->menu_view_back = view_menu_uiinfo[0].widget;
     main_menu->priv->menu_view_forward = view_menu_uiinfo[1].widget;
 
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_conbuttons),
-        gnome_cmd_data_get_conbuttons_visibility ());
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_toolbar),
-        gnome_cmd_data_get_toolbar_visibility ());
+        gnome_cmd_data.toolbar_visibility);
+    gtk_check_menu_item_set_active (
+        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_conbuttons),
+        gnome_cmd_data.conbuttons_visibility);
+    gtk_check_menu_item_set_active (
+        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_concombo),
+        gnome_cmd_data.concombo_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_buttonbar),
-        gnome_cmd_data_get_buttonbar_visibility ());
+        gnome_cmd_data.buttonbar_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_cmdline),
-        gnome_cmd_data_get_cmdline_visibility ());
+        gnome_cmd_data.cmdline_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_hidden_files),
-        !gnome_cmd_data_get_hidden_filter ());
+        !gnome_cmd_data.filter_settings.hidden);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_backup_files),
-        !gnome_cmd_data_get_backup_filter ());
+        !gnome_cmd_data.filter_settings.backup);
 
-    gtk_signal_connect (GTK_OBJECT (gnome_cmd_data_get_con_list ()), "list-changed",
+    gtk_signal_connect (GTK_OBJECT (gnome_cmd_con_list_get ()), "list-changed",
                         GTK_SIGNAL_FUNC (on_con_list_list_changed), main_menu);
 
     gnome_cmd_main_menu_update_bookmarks (main_menu);
@@ -867,15 +888,13 @@ init (GnomeCmdMainMenu *main_menu)
  * Public functions
  ***********************************/
 
-GtkWidget *
-gnome_cmd_main_menu_new (void)
+GtkWidget *gnome_cmd_main_menu_new ()
 {
     return (GtkWidget *) gtk_type_new (gnome_cmd_main_menu_get_type ());
 }
 
 
-GtkType
-gnome_cmd_main_menu_get_type         (void)
+GtkType gnome_cmd_main_menu_get_type ()
 {
     static GtkType dlg_type = 0;
 
@@ -899,10 +918,7 @@ gnome_cmd_main_menu_get_type         (void)
 }
 
 
-static void
-add_connection (GnomeCmdMainMenu *main_menu, GnomeCmdCon *con,
-                const gchar *text, GnomeCmdPixmap *pixmap,
-                GtkSignalFunc func)
+static void add_connection (GnomeCmdMainMenu *main_menu, GnomeCmdCon *con, const gchar *text, GnomeCmdPixmap *pixmap, GtkSignalFunc func)
 {
     GtkMenuShell *connections_menu =GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
     GtkWidget *item;
@@ -913,19 +929,18 @@ add_connection (GnomeCmdMainMenu *main_menu, GnomeCmdCon *con,
 }
 
 
-void
-gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
+void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
     GtkMenuShell *connections_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
-    GnomeCmdConList *con_list = gnome_cmd_data_get_con_list ();
+    GnomeCmdConList *con_list = gnome_cmd_con_list_get ();
     GList *all_cons = gnome_cmd_con_list_get_all (con_list);
-    GList *ftp_cons = gnome_cmd_con_list_get_all_ftp (con_list);
-    GList *dev_cons = gnome_cmd_con_list_get_all_dev (con_list);
+    // GList *ftp_cons = gnome_cmd_con_list_get_all_ftp (con_list);
+    // GList *dev_cons = gnome_cmd_con_list_get_all_dev (con_list);
 
     // Remove all old items
-    g_list_foreach (main_menu->priv->connections_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->connections_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->connections_menuitems);
     main_menu->priv->connections_menuitems = NULL;
 
@@ -967,25 +982,22 @@ gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
 }
 
 
-void
-gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
+void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
 {
-    GList *cons;
-
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
     // Remove all old bookmark menu items
-    g_list_foreach (main_menu->priv->bookmark_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->bookmark_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->bookmark_menuitems);
     main_menu->priv->bookmark_menuitems = NULL;
 
     // Remove all old group menu items
-    g_list_foreach (main_menu->priv->group_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->group_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->group_menuitems);
     main_menu->priv->group_menuitems = NULL;
 
     // Add bookmark groups
-    cons = gnome_cmd_con_list_get_all (gnome_cmd_data_get_con_list ());
+    GList *cons = gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ());
     for (; cons; cons = cons->next)
     {
         GnomeCmdCon *con = GNOME_CMD_CON (cons->data);
@@ -997,34 +1009,27 @@ gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
 }
 
 
-void
-gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu)
+void gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu)
 {
-    GnomeCmdFileSelector *fs;
-
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
-    fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
+    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
 
-    gtk_widget_set_sensitive (main_menu->priv->menu_view_back, gnome_cmd_file_selector_can_back (fs));
-    gtk_widget_set_sensitive (main_menu->priv->menu_view_forward, gnome_cmd_file_selector_can_forward (fs));
+    gtk_widget_set_sensitive (main_menu->priv->menu_view_back, fs->can_back());
+    gtk_widget_set_sensitive (main_menu->priv->menu_view_forward, fs->can_forward());
 }
 
 
-static void
-on_plugin_menu_activate (GtkMenuItem *item, PluginData *data)
+static void on_plugin_menu_activate (GtkMenuItem *item, PluginData *data)
 {
-    GnomeCmdState *state;
-
     g_return_if_fail (data != NULL);
 
-    state = gnome_cmd_main_win_get_state (main_win);
+    GnomeCmdState *state = gnome_cmd_main_win_get_state (main_win);
     gnome_cmd_plugin_update_main_menu_state (data->plugin, state);
 }
 
 
-void
-gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *data)
+void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *data)
 {
     gtk_menu_shell_append (GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->plugins_menu)->submenu), data->menu);
 
