@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +21,6 @@
 #ifndef __GNOME_CMD_SMB_NET_H__
 #define __GNOME_CMD_SMB_NET_H__
 
-G_BEGIN_DECLS
-
 typedef enum
 {
     SMB_WORKGROUP,
@@ -29,20 +28,16 @@ typedef enum
 } SmbEntityType;
 
 
-typedef struct
+struct SmbEntity
 {
     gchar *name;
     SmbEntityType type;
 
     // this one is only set if type == SMB_HOST and
     gchar *workgroup_name;
-} SmbEntity;
+};
 
 
-
-SmbEntity *
-gnome_cmd_smb_net_get_entity (const gchar *name);
-
-G_END_DECLS
+SmbEntity *gnome_cmd_smb_net_get_entity (const gchar *name);
 
 #endif // __GNOME_CMD_SMB_NET_H__
